==> ejc-businessplan-impl-3.0.0-20220225.080726-13-sources.jar: com/ejianc/business/record/bean/RecordcountersignatureEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 商务会签变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_businessplan_countersignature")
public class RecordcountersignatureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="countersignature_id")
    private java.lang.Long countersignatureId; // 商务会签id
    @TableField(value="countersignature_code")
    private java.lang.Long countersignatureCode; // 商务会签变更编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="planning_name")
    private java.lang.String planningName; // 策划名称
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人名称
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="effect_time")
    private java.util.Date effectTime; // 生效时间
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    
    
    

    /**
     * 商务会签id
     */
    public java.lang.Long getCountersignatureId() {
        return countersignatureId;
    }

    /**
     * 商务会签id
     */
    public void setCountersignatureId(java.lang.Long countersignatureId) {
        this.countersignatureId = countersignatureId;
    }
    /**
     * 商务会签变更编码
     */
    public java.lang.Long getCountersignatureCode() {
        return countersignatureCode;
    }

    /**
     * 商务会签变更编码
     */
    public void setCountersignatureCode(java.lang.Long countersignatureCode) {
        this.countersignatureCode = countersignatureCode;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 策划名称
     */
    public java.lang.String getPlanningName() {
        return planningName;
    }

    /**
     * 策划名称
     */
    public void setPlanningName(java.lang.String planningName) {
        this.planningName = planningName;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20220322.014410-24-sources.jar: com/ejianc/business/record/bean/RecordcountersignatureEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 商务会签变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_businessplan_countersignature")
public class RecordcountersignatureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="countersignature_id")
    private java.lang.Long countersignatureId; // 商务会签id
    @TableField(value="countersignature_code")
    private java.lang.String countersignatureCode; // 商务会签变更编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="planning_name")
    private java.lang.String planningName; // 策划名称
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人名称
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="effect_time")
    private java.util.Date effectTime; // 生效时间
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    
    
    

    /**
     * 商务会签id
     */
    public java.lang.Long getCountersignatureId() {
        return countersignatureId;
    }

    /**
     * 商务会签id
     */
    public void setCountersignatureId(java.lang.Long countersignatureId) {
        this.countersignatureId = countersignatureId;
    }
    /**
     * 商务会签变更编码
     */
    public java.lang.String getCountersignatureCode() {
        return countersignatureCode;
    }

    /**
     * 商务会签变更编码
     */
    public void setCountersignatureCode(java.lang.String countersignatureCode) {
        this.countersignatureCode = countersignatureCode;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 策划名称
     */
    public java.lang.String getPlanningName() {
        return planningName;
    }

    /**
     * 策划名称
     */
    public void setPlanningName(java.lang.String planningName) {
        this.planningName = planningName;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
}
